<?php
namespace Estoque\Entities;

/**
 *
 * @method \Estoque\Entities\Lanctoestoq findOneByCdfilialAndNrlanctonfAndNrorg($cdfilial, $nrlanctonf, $nrorg) static
 * @method findOneByCdfilialAndDtlancestqAndNrorg ($cdfilial, $dtlancamento, $nrorg) static
 */
class Lanctoestoq extends Base\Lanctoestoq
{


    /**
     * IDSTATUSCTBEST = "P": Identificador Pendente de contabilização do estoque.
     */
    const CONTABILIZACAO_PENDENTE  = "P";
    /**
     * IDSTATUSCTBEST = "C": Identificador Contabilizado de contabilização do estoque.
     */
    const CONTABILIZACAO_CONTABILIZADO  = "C";
    /**
     * IDSTATUSCTBEST = "E": Identificador Erro de Contabilizacao de contabilização do estoque.
     */
    const CONTABILIZACAO_ERRO_CONSTABILIZACAO  = "E";
    /**
     * IDSTATUSCTBEST = "R": Identificador Recontabilizar de contabilização do estoque.
     */
    const CONTABILIZACAO_RECONTABILIZAR  = "R";
    /**
     * IDTPLANCTO = 0: lancamento de implnatacao de estoque.
     */
    const LANCAMENTO_IMPLANTACAO_DE_ESTOQUE  = "0";
    /**
     * IDTPLANCTO = 1: lancamento de ajuste de inventario.
     */
    const LANCAMENTO_AJUSTE_DE_INVENTARIO    = "1";
    /**
     * IDTPLANCTO = 2: lancamento de entrada de estoque.
     */
    const LANCAMENTO_ENTRADA_NO_ESTOQUE      = "2";
    /**
     * IDTPLANCTO = 3: lancamento de retirada de estoque.
     */
    const LANCAMENTO_RETIRADA_DE_ESTOQUE     = "3";
    /**
     * IDTPLANCTO = 4: lancamento de saida de estoque.
     */
    const LANCAMENTO_SAIDA_DE_ESTOQUE        = "4";
    /**
     * IDTPLANCTO = 5: lancamento de devolucao de estoque.
     */
    const LANCAMENTO_DEVOLUCAO_AO_FORNECEDOR = "5";
    /**
     * IDTPLANCTO = E: lancamento de documento fiscal de entrada.
     */
    const LANCAMENTO_DOC_FISCAL_DE_ENTRADA   = "E";
    /**
     * IDTPLANCTO = S: lancamento de documento fiscal de saida.
     */
    const LANCAMENTO_DOC_FISCAL_DE_SAIDA     = "S";

    /**
     * Prefixo do CDCONTADOR da tabela de lanctoestoq para os registros de novocodigo.
     */
    const CDCONTADOR_LANCTOESTOQ             = "LANCTOEST";


    CONST SIM = 'S';
    CONST NAO = 'N';


    public function insere(
        $nrlancestq, $cdoperador, $cdfilial, $cdfilimovi, $idtplancto, $dtlancestq, $dslancestq, $nrorg,  $cdalmoxarife = null, $cdlocalestoq = null
    ){
        try {
            $dtAtual = \Geral\Util\DateUtil::getDataAtual();

            if (is_object($dtlancestq) === false) {
                list($dtlancestq) = explode(' ', $dtlancestq);
                $dtLancamento = \Geral\Util\DateUtil::getDataDeString($dtlancestq);
            } else {
                $dtLancamento = $dtlancestq;
            }
            
            $dtLancamento = \Geral\Util\DateUtil::truncateData($dtLancamento);

            $this->setNrorg($nrorg);
            $this->setNrorginclusao($nrorg);
            $this->setCdalmoxarife($cdalmoxarife);
            $this->setCdlocalestoq($cdlocalestoq);
            $this->setNrlancestq($nrlancestq);
            $this->setCdoperador($cdoperador);
            $this->setCdoperinclusao($cdoperador);
            $this->setCdfilial($cdfilial);
            $this->setCdfilimovi($cdfilimovi);
            $this->setIdtplancto($idtplancto);
            $this->setDtlancestq($dtLancamento);
            $this->setDslancestq($dslancestq);
            $this->setDtinclusao($dtAtual);
            $this->setDtultatu($dtAtual);
            $this->setIdaltcusmed('N');
            $this->setIdstatusctbest(self::CONTABILIZACAO_PENDENTE);

            $this->persist();
            return $this;
        } catch (\Exception $e) {
            throw $e;
        }
    }


    public function atualizaLancamento($desc, $dt, $operAtual, $nrorgAtual){
        $dtAtual = \Geral\Util\DateUtil::getDataAtual();
        list($dt) = explode(' ', $dt);
        $dtLanc  = \Geral\Util\DateUtil::getDataDeString($dt);
        $dtLanc  = \Geral\Util\DateUtil::truncateData($dtLanc);

        $this->setDslancestq($desc);
        $this->setDtlancestq($dtLanc);
        $this->setDtultatu($dtAtual);
        $this->setCdoperultatu($operAtual);
        $this->setNrorgultatu($nrorgAtual);

        $this->persist();
        return $this;
    }


    public static function consultaLancamento($nrorg, $filial, $nrLancto)
    {
        /** @var $lancto Lanctoestoq */
        $lancto = Lanctoestoq::getObjectByWhere(
            'NRORG = ? AND CDFILIMOVI = ? AND NRLANCESTQ = ?',
            array($nrorg, $filial, $nrLancto)
        );

        return $lancto;
    }

}