/******************************************************************************/
/* Sistemas Integrados TECNISA                                                */
/*                                                                            */
/* Qualidade de Fornecimento                                                  */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* Nome: 8520_QFOSTP_DUPLICA_QFOMARPROD                                       */
/*                                                                            */
/* Descrio:                                                                 */
/* Duplica um cadastro de Qualificao de Marca por Produto e cria testes de  */
/* produto para as qualificaes duplicadas.                                  */
/*                                                                            */
/*                                                                            */
/* Criao:                                                                   */
/* 15/08/2000 - Joo Fernando dos Reis Corra                                 */
/*                                                                            */
/*                                                                            */
/******************************************************************************/
/******************************************************************************/
/* PARAMETROS:                                                                */
/* @P_PRODORIGEM  -  Produto de origem dos dados a serem duplicados.          */
/* @P_PRODINI     -  Produto de destino inicial do intervalo.                 */
/* @P_PRODFIN     -  Produto de destino final do intervalo.                   */
/* @P_CDMARCA     -  Marcas escolhidas no filtro para a exportao            */
/******************************************************************************/
/* @C:\SISTEMAS\DBA\SQL\ORACLE\8520_QFOSTP_DUPLICA_QFOMARPROD.SQL             */
/* @H:\SISTEMAS\DBA\SQL\ORACLE\8520_QFOSTP_DUPLICA_QFOMARPROD.SQL             */
/******************************************************************************/
IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
                    WHERE
                       O.NAME = 'DUPLICA_QFOMARPROD'  AND
                       TYPE = 'P'                  AND
                       U.UID = O.UID               AND
                       U.NAME = USER)

   DROP PROCEDURE DUPLICA_QFOMARPROD
   GO

CREATE PROCEDURE DUPLICA_QFOMARPROD  @P_PRODORIGEM VARCHAR(20),
                                     @P_PRODINI    VARCHAR(20),
                                     @P_PRODFIN    VARCHAR(20),
                                     @P_CDMARCA    VARCHAR(2000),
                                     @P_ATUALIQUALI VARCHAR(1),
                                     @P_GERATESTE   VARCHAR(1),
                                     @P_ATUALITESTE VARCHAR(1)
AS

 DECLARE @V_TCDMARCA    VARCHAR(1);
 DECLARE @V_PROXTESTE   VARCHAR(20);
 DECLARE @V_DATATESTE   DATETIME;
 DECLARE @V_CDPRODUTO   VARCHAR(10);
 DECLARE @V_PRODORIGEM  VARCHAR(10);
 DECLARE @V_CDMARCA     VARCHAR(5);
 DECLARE @V_IDAPRMARPRO VARCHAR(1);
 DECLARE @V_IDAUTMARPRO VARCHAR(1);
 DECLARE @V_DTVALAPROVA DATETIME;
 DECLARE @V_VRRENDATU   NUMERIC;
 DECLARE @V_IDRENMARPRO VARCHAR(1);
 DECLARE @V_NRTESTEPROD VARCHAR(10);
 DECLARE @V_DTTESTEQUA  DATETIME;
 DECLARE @V_COUNT NUMERIC;
 DECLARE @V_COUNT_TESTE NUMERIC;

BEGIN
   SET @V_TCDMARCA = NULL;

   IF @P_CDMARCA IS NULL
   BEGIN
      SET @V_TCDMARCA = 'T';
   END;

   DECLARE C_PRODDEST CURSOR FOR
   SELECT
      PRODUTO.CDPRODUTO,
      QFOMARPROD.CDMARCA,
      QFOMARPROD.CDPRODUTO AS PRODORIGEM,
      QFOMARPROD.IDAPRMARPRO,
      QFOMARPROD.IDAUTMARPRO,
      QFOMARPROD.DTVALAPROVA,
      QFOMARPROD.VRRENDATU,
      QFOMARPROD.IDRENMARPRO,
      QFOMARPROD.NRTESTEPROD,
      QFOMARPROD.DTTESTEQUA
   FROM
      QFOMARPROD,
      PRODUTO,
      PRODUTO P
   WHERE
      (PRODUTO.CDARVPROD BETWEEN @P_PRODINI AND @P_PRODFIN) AND
      (PRODUTO.CDPRODESTO IS NOT NULL)              AND
      (P.CDPRODUTO = QFOMARPROD.CDPRODUTO) AND
      (P.CDARVPROD = @P_PRODORIGEM)                AND
      (CHARINDEX(QFOMARPROD.CDMARCA, @P_CDMARCA)<> 0 OR @V_TCDMARCA = 'T');

   OPEN C_PRODDEST;
   FETCH NEXT FROM C_PRODDEST INTO @V_CDPRODUTO,
                                   @V_CDMARCA,
                                   @V_PRODORIGEM,
                                   @V_IDAPRMARPRO,
                                   @V_IDAUTMARPRO,
                                   @V_DTVALAPROVA,
                                   @V_VRRENDATU,
                                   @V_IDRENMARPRO,
                                   @V_NRTESTEPROD,
                                   @V_DTTESTEQUA

   WHILE (@@FETCH_STATUS = 0)
   BEGIN
      SET @V_DATATESTE = @V_DTTESTEQUA;
      INSERT INTO MARCPROD
         (CDPRODUTO, CDMARCA)
         (SELECT
             CDPRODUTO,
             @V_CDMARCA
          FROM
             PRODUTO
          WHERE
             PRODUTO.CDPRODUTO = @V_CDPRODUTO AND
             NOT EXISTS (SELECT
                            MARCPROD.CDMARCA,
                            MARCPROD.CDPRODUTO
                         FROM
                            MARCPROD, PRODUTO PR
                         WHERE
                            MARCPROD.CDPRODUTO = PR.CDPRODUTO AND
                            MARCPROD.CDMARCA = @V_CDMARCA AND
                            PRODUTO.CDARVPROD LIKE PR.CDARVPROD + '%'));
       INSERT INTO MARCPRODCOMP
         (CDPRODUTO, CDMARCA, CDPRMARCOMPL)
         (SELECT
             CDPRODUTO,
             @V_CDMARCA,
             CDPRODUTO
          FROM
             PRODUTO
          WHERE
             PRODUTO.CDPRODUTO = @V_CDPRODUTO AND
             NOT EXISTS (SELECT
                            MARCPRODCOMP.CDMARCA,
                            MARCPRODCOMP.CDPRODUTO
                         FROM
                            MARCPRODCOMP,
                            PRODUTO PR
                         WHERE
                            MARCPRODCOMP.CDPRODUTO = PR.CDPRODUTO AND
                            MARCPRODCOMP.CDMARCA = @V_CDMARCA AND
                            PRODUTO.CDARVPROD LIKE PR.CDARVPROD + '%'));

      SET @V_COUNT_TESTE = NULL;
      SELECT
         @V_COUNT_TESTE = NRTESTEPROD
      FROM
         TESTEPROD A
      WHERE
         A.CDPRODUTO = @V_CDPRODUTO AND
         A.CDMARCA   = @V_CDMARCA

      IF @V_COUNT_TESTE = 0 BEGIN
      	IF @P_GERATESTE = 'S' BEGIN

         	EXEC NOVO_CODIGO 'TESTEPROD', @P_SEQUENCIAL = @V_PROXTESTE OUTPUT, @P_QTDE = 1;

            INSERT INTO TESTEPROD
            (NRTESTEPROD,  DTTESTE,      CDPRODUTO,
            CDMARCA,      CDFORNECED,   NMRESPTESTE,
            IDMARCAPRTES, DTVALAPRTEST, VRRENDATUTES,
            DSRENDATUAL,  IDTIPREN,     NMFABROPCTES,
            NMTIPOEMBAL,  IDEMBDATVAL,  DSREGISTTEST,
            IDASPVISUAL,  IDASPCOR,     IDASPODOR,
            IDASPSABOR,   IDASPTEXT,    IDTESTBROM,
            IDPRATEMB,    IDPRATMANIP,  HRTEMPOELAB)
            (SELECT
                SUBSTRING(@V_PROXTESTE, 11, 10), GETDATE(),    @V_CDPRODUTO,
                @V_CDMARCA,   CDFORNECED,   NMRESPTESTE,
                IDMARCAPRTES, DTVALAPRTEST, VRRENDATUTES,
                DSRENDATUAL,  IDTIPREN,     NMFABROPCTES,
                NMTIPOEMBAL,  IDEMBDATVAL,  DSREGISTTEST,
                IDASPVISUAL,  IDASPCOR,     IDASPODOR,
                IDASPSABOR,   IDASPTEXT,    IDTESTBROM,
                IDPRATEMB,    IDPRATMANIP,  HRTEMPOELAB
             FROM
                TESTEPROD
             WHERE
                NRTESTEPROD = @V_NRTESTEPROD);

             IF @@ROWCOUNT = 0 BEGIN
                SET @V_PROXTESTE = NULL;
                SET @V_DATATESTE = NULL;
             END
             ELSE BEGIN
                IF @P_ATUALIQUALI = 'N' BEGIN
                   UPDATE QFOMARPROD
                   SET NRTESTEPROD = SUBSTRING(@V_PROXTESTE, 11, 10)
                   WHERE CDPRODUTO = @V_CDPRODUTO AND
                         CDMARCA = @V_CDMARCA;
                END;
             END;
         END;
      END
      ELSE BEGIN
      	SET @V_PROXTESTE = NULL;
         SET @V_DATATESTE = NULL;

         IF @P_ATUALITESTE = 'S' BEGIN
            IF @V_NRTESTEPROD IS NULL BEGIN
                  UPDATE TESTEPROD
                  SET DTVALAPRTEST = @V_DTVALAPROVA,
                      IDMARCAPRTES = @V_IDAPRMARPRO
                  WHERE
                     CDPRODUTO = @V_CDPRODUTO AND
                     CDMARCA   = @V_CDMARCA AND
                     EXISTS (SELECT CDPRODUTO
                             FROM TESTEPROD T
                             WHERE T.CDPRODUTO = @V_PRODORIGEM AND
                                   T.CDMARCA = TESTEPROD.CDMARCA);
            END
            ELSE BEGIN
               UPDATE TESTEPROD
               SET  DTTESTE = GETDATE(),
                    CDFORNECED = (SELECT CDFORNECED
                                  FROM TESTEPROD
                                  WHERE NRTESTEPROD = @V_NRTESTEPROD),

                    NMRESPTESTE = (SELECT NMRESPTESTE
                                   FROM TESTEPROD
                                   WHERE NRTESTEPROD = @V_NRTESTEPROD),

                    IDMARCAPRTES = (SELECT IDMARCAPRTES
                                    FROM TESTEPROD
                                    WHERE NRTESTEPROD = @V_NRTESTEPROD),

                    DTVALAPRTEST = (SELECT DTVALAPRTEST
                                    FROM TESTEPROD
                                    WHERE NRTESTEPROD = @V_NRTESTEPROD),

                    VRRENDATUTES = (SELECT VRRENDATUTES
                                    FROM TESTEPROD
                                    WHERE NRTESTEPROD = @V_NRTESTEPROD),

                    DSRENDATUAL  = (SELECT DSRENDATUAL
                                    FROM TESTEPROD
                                    WHERE NRTESTEPROD = @V_NRTESTEPROD),

                    IDTIPREN     = (SELECT IDTIPREN
                                    FROM TESTEPROD
                                    WHERE NRTESTEPROD = @V_NRTESTEPROD),

                    NMFABROPCTES = (SELECT NMFABROPCTES
                                    FROM TESTEPROD
                                    WHERE NRTESTEPROD = @V_NRTESTEPROD),

                    NMTIPOEMBAL  = (SELECT NMTIPOEMBAL
                                    FROM TESTEPROD
                                    WHERE NRTESTEPROD = @V_NRTESTEPROD),

                    IDEMBDATVAL  = (SELECT IDEMBDATVAL
                                    FROM TESTEPROD
                                    WHERE NRTESTEPROD = @V_NRTESTEPROD),

                    DSREGISTTEST = (SELECT DSREGISTTEST
                                    FROM TESTEPROD
                                    WHERE NRTESTEPROD = @V_NRTESTEPROD),

                    IDASPVISUAL  = (SELECT IDASPVISUAL
                                    FROM TESTEPROD
                                    WHERE NRTESTEPROD = @V_NRTESTEPROD),

                    IDASPCOR     = (SELECT IDASPCOR
                                    FROM TESTEPROD
                                    WHERE NRTESTEPROD = @V_NRTESTEPROD),

                    IDASPODOR    = (SELECT IDASPODOR
                                    FROM TESTEPROD
                                    WHERE NRTESTEPROD = @V_NRTESTEPROD),

                    IDASPSABOR   = (SELECT IDASPSABOR
                                    FROM TESTEPROD
                                    WHERE NRTESTEPROD = @V_NRTESTEPROD),

                    IDASPTEXT    = (SELECT IDASPTEXT
                                    FROM TESTEPROD
                                    WHERE NRTESTEPROD = @V_NRTESTEPROD),

                    IDTESTBROM   = (SELECT IDTESTBROM
                                    FROM TESTEPROD
                                    WHERE NRTESTEPROD = @V_NRTESTEPROD),

                    IDPRATEMB    = (SELECT IDPRATEMB
                                    FROM TESTEPROD
                                    WHERE NRTESTEPROD = @V_NRTESTEPROD),

                    IDPRATMANIP  = (SELECT IDPRATMANIP
                                    FROM TESTEPROD
                                    WHERE NRTESTEPROD = @V_NRTESTEPROD),

                    HRTEMPOELAB   = (SELECT HRTEMPOELAB
                                    FROM TESTEPROD
                                    WHERE NRTESTEPROD = @V_NRTESTEPROD)
               WHERE
                  CDPRODUTO = @V_CDPRODUTO AND
                  CDMARCA   = @V_CDMARCA;
            END;
         END;
      END;

      SET @V_COUNT = 0;
      SELECT
      	@V_COUNT = COUNT(*)
      FROM
         QFOMARPROD
      WHERE
         QFOMARPROD.CDPRODUTO = @V_CDPRODUTO AND
         QFOMARPROD.CDMARCA   = @V_CDMARCA

      IF @V_COUNT = 0 BEGIN
         INSERT INTO QFOMARPROD
         (CDMARCA,
          CDPRODUTO,
          IDAPRMARPRO,
          IDAUTMARPRO,
          DTVALAPROVA,
          VRRENDATU,
          IDRENMARPRO,
          NRTESTEPROD,
          DTTESTEQUA)

          VALUES(@V_CDMARCA,
                 @V_CDPRODUTO,
                 @V_IDAPRMARPRO,
                 @V_IDAUTMARPRO,
                 @V_DTVALAPROVA,
                 @V_VRRENDATU,
                 @V_IDRENMARPRO,
                 CASE @P_GERATESTE
                      WHEN 'S' THEN SUBSTRING(@V_PROXTESTE, 11, 10)
                      ELSE NULL
                 END,
                 CASE @P_GERATESTE
                      WHEN 'S' THEN @V_DATATESTE
                      ELSE NULL
                 END);

   	END
      ELSE IF @P_ATUALIQUALI = 'S' BEGIN
      	UPDATE QFOMARPROD
         SET IDAPRMARPRO = @V_IDAPRMARPRO,
             IDAUTMARPRO = @V_IDAUTMARPRO,
             DTVALAPROVA = @V_DTVALAPROVA,
             VRRENDATU   = @V_VRRENDATU,
             IDRENMARPRO = @V_IDRENMARPRO,
             NRTESTEPROD = ISNULL(SUBSTRING(@V_PROXTESTE, 11, 10),NRTESTEPROD),
             DTTESTEQUA  = ISNULL(SUBSTRING(CONVERT(VARCHAR,@V_DATATESTE), 11, 10),DTTESTEQUA)
         WHERE
            QFOMARPROD.CDPRODUTO = @V_CDPRODUTO AND
            QFOMARPROD.CDMARCA   = @V_CDMARCA;
		END;
      FETCH NEXT FROM C_PRODDEST INTO @V_CDPRODUTO,
                                      @V_CDMARCA,
                                      @V_PRODORIGEM,
                                      @V_IDAPRMARPRO,
                                      @V_IDAUTMARPRO,
                                      @V_DTVALAPROVA,
                                      @V_VRRENDATU,
                                      @V_IDRENMARPRO,
                                      @V_NRTESTEPROD,
                                      @V_DTTESTEQUA

   END;
   CLOSE C_PRODDEST;
   DEALLOCATE C_PRODDEST;
END;
GO
