import {
  Metadata, Http, Loader, IEventParam,
} from '@zeedhi/core';

import {
  Select, SelectMultiple, Form, Modal, ModalService, DialogService, GridEditable,
} from '@zeedhi/common';
  
export class Pme02401ClientesPorServicoModalController {
  public appController = Loader.getInstance('AppController');

  public crudController = Loader.getInstance('CrudController');

  public gridEditController = Loader.getInstance('GridEditableController');

  public utilities = Loader.getInstance('Utilities');
  
  public modalController = Loader.getInstance('ModalController');
  
  private modalConfigCard!: Modal;
  
  public async criaModalClientesPorServico() {
    this.modalController.createModal('pme/servico/modals/pme02401_clientes_por_servico_modal');
    this.modalConfigCard = await ModalService.createFromJsonPost('', { jsonPath: 'modals/closeButtonModal' });
  }
  
  public destroiModalClientesPorServico() {
    this.modalController.destroyModal();
  }
  
  public cancelaModalClientesPorServico() {
    const unidade = Metadata.getInstance<Select>('unidadeCdFilialModal');
    unidade.setValue('');
    this.modalConfigCard.hide();
    this.modalConfigCard.destroy();
    this.modalController.closeModal();
  }
  
  public abreModalClientesPorServico() {
    this.modalController.openModal();
    this.clearFields();
  }
  
  public clearFields() {
    const tpCardServ = Metadata.getInstance<Select>('TpCardapioPorServicoModal');
    tpCardServ.setValue('');
  }
  
  public setTpCardServ({ component }: IEventParam<SelectMultiple>) {
    const cdfilial = Metadata.getInstance<Select>('unidadeCdFilialModal');
    const filter = [
      {
        name: 'CDFILIAL',
        operator: '=',
        value: cdfilial.value ? cdfilial.value : null,
      },
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: this.appController.getCdCentral(),
      },
    ];
    
    component.datasource.filter = filter;
    component.datasource.get();
  }
  
  public realizaAcaoCadastroAutomaticoCliente() {
    const selectCardPorServ = Metadata.getInstance<SelectMultiple>('TpCardapioPorServicoModal');
    const selectCliente = Metadata.getInstance<Select>('clienteModalSelect');
    const selectUnidade = Metadata.getInstance<Select>('unidadeCdFilialModal');
    const gridClientes = Metadata.getInstance<GridEditable>('gridClientes');
    const unidade = selectUnidade.selectValue;
    const cliente = selectCliente.selectValue;
    const linhasCardPorServ = selectCardPorServ.selectValue;
    Http.post('/acaoCadastroAutomaticoCliente', { unidade, cliente, linhasCardPorServ }).then(() => {
      DialogService.hide();
      this.utilities.showAlert('alert', 'pme::cadastroAutomaticoDeClienteSucesso', 'success');
      gridClientes.datasource.get();
    }).catch((error: string) => {
      this.utilities.showAlert('alertError', `pme::${error}`, 'error');
      DialogService.hide();
    });
  }
  
  public confirmaAcaoCadastroAutomaticoCliente() {
    const formModal = Metadata.getInstance<Form>('formModalClientesPorServico');
    if (this.utilities.centralIsValid() && formModal.validate()) {
      DialogService.show({
        name: 'confirmaAcaoCadastroAutomatico',
        type: 'warning',
        title: 'pme::atencao',
        text: 'pme::desejaCadastrarAutomaticoClientes',
        buttons: [
          {
            name: 'yes',
            component: 'ZdButton',
            label: 'pme::sim',
            events: { click: () => this.realizaAcaoCadastroAutomaticoCliente() },
            outline: true,
          },
          {
            name: 'no',
            component: 'ZdButton',
            label: 'pme::nao',
            events: { click: () => DialogService.hide() },
          },
        ],
      });
    }
  }
}
